@@ -66,6 +66,7 @@
 #![feature(generic_assert_internals)]
 #![feature(hasher_prefixfree_extras)]
 #![feature(hashmap_internals)]
+#![feature(int_from_ascii)]
 #![feature(int_lowest_highest_one)]
 #![feature(int_roundings)]
 #![feature(ip)]
@@ -90,6 +91,7 @@
 #![feature(new_range_api)]
 #![feature(next_index)]
 #![feature(non_exhaustive_omitted_patterns_lint)]
+#![feature(nonzero_from_str_radix)]
 #![feature(numfmt)]
 #![feature(one_sided_range)]
 #![feature(option_reduce)]
